==> imp-doc-2.0.1.tar.gz: html/namespaceIMP_1_1em2d.js <==
var namespaceIMP_1_1em2d =
[
    [ "buildxlinks", null, [
      [ "DockOrder", "classIMP_1_1em2d_1_1buildxlinks_1_1DockOrder.html", "classIMP_1_1em2d_1_1buildxlinks_1_1DockOrder" ],
      [ "InitialDockingFromXlinks", "classIMP_1_1em2d_1_1buildxlinks_1_1InitialDockingFromXlinks.html", "classIMP_1_1em2d_1_1buildxlinks_1_1InitialDockingFromXlinks" ],
      [ "Xlink", "classIMP_1_1em2d_1_1buildxlinks_1_1Xlink.html", "classIMP_1_1em2d_1_1buildxlinks_1_1Xlink" ],
      [ "XlinksDict", "classIMP_1_1em2d_1_1buildxlinks_1_1XlinksDict.html", "classIMP_1_1em2d_1_1buildxlinks_1_1XlinksDict" ]
    ] ],
    [ "Database", null, [
      [ "Database2", "classIMP_1_1em2d_1_1Database_1_1Database2.html", "classIMP_1_1em2d_1_1Database_1_1Database2" ]
    ] ],
    [ "DominoModel", null, [
      [ "DominoModel", "classIMP_1_1em2d_1_1DominoModel_1_1DominoModel.html", "classIMP_1_1em2d_1_1DominoModel_1_1DominoModel" ]
    ] ],
    [ "MonteCarloRelativeMoves", null, [
      [ "MonteCarloRelativeMoves", "classIMP_1_1em2d_1_1MonteCarloRelativeMoves_1_1MonteCarloRelativeMoves.html", "classIMP_1_1em2d_1_1MonteCarloRelativeMoves_1_1MonteCarloRelativeMoves" ]
    ] ],
    [ "solutions_io", null, [
      [ "ClusterRecord", "classIMP_1_1em2d_1_1solutions__io_1_1ClusterRecord.html", null ],
      [ "HeapRecord", "classIMP_1_1em2d_1_1solutions__io_1_1HeapRecord.html", null ],
      [ "ResultsDB", "classIMP_1_1em2d_1_1solutions__io_1_1ResultsDB.html", "classIMP_1_1em2d_1_1solutions__io_1_1ResultsDB" ]
    ] ],
    [ "CenteredMat", "classIMP_1_1em2d_1_1CenteredMat.html", "classIMP_1_1em2d_1_1CenteredMat" ],
    [ "ChiSquaredScore", "classIMP_1_1em2d_1_1ChiSquaredScore.html", "classIMP_1_1em2d_1_1ChiSquaredScore" ],
    [ "DistanceFilterTable", "classIMP_1_1em2d_1_1DistanceFilterTable.html", "classIMP_1_1em2d_1_1DistanceFilterTable" ],
    [ "DummyRestraint", "classIMP_1_1em2d_1_1DummyRestraint.html", "classIMP_1_1em2d_1_1DummyRestraint" ],
    [ "Em2DRestraint", "classIMP_1_1em2d_1_1Em2DRestraint.html", "classIMP_1_1em2d_1_1Em2DRestraint" ],
    [ "EM2DScore", "classIMP_1_1em2d_1_1EM2DScore.html", "classIMP_1_1em2d_1_1EM2DScore" ],
    [ "Fine2DRegistrationRestraint", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint" ],
    [ "GridStates", "classIMP_1_1em2d_1_1GridStates.html", "classIMP_1_1em2d_1_1GridStates" ],
    [ "HasHigherCCC", "classIMP_1_1em2d_1_1HasHigherCCC.html", "classIMP_1_1em2d_1_1HasHigherCCC" ],
    [ "HasLowerScore", "classIMP_1_1em2d_1_1HasLowerScore.html", "classIMP_1_1em2d_1_1HasLowerScore" ],
    [ "Image", "classIMP_1_1em2d_1_1Image.html", "classIMP_1_1em2d_1_1Image" ],
    [ "JPGImageReaderWriter", "classIMP_1_1em2d_1_1JPGImageReaderWriter.html", "classIMP_1_1em2d_1_1JPGImageReaderWriter" ],
    [ "LessPairBySecond", "classIMP_1_1em2d_1_1LessPairBySecond.html", "classIMP_1_1em2d_1_1LessPairBySecond" ],
    [ "MasksManager", "classIMP_1_1em2d_1_1MasksManager.html", "classIMP_1_1em2d_1_1MasksManager" ],
    [ "MatchTemplateResult", "classIMP_1_1em2d_1_1MatchTemplateResult.html", "classIMP_1_1em2d_1_1MatchTemplateResult" ],
    [ "ParticlesDummyRestraint", "classIMP_1_1em2d_1_1ParticlesDummyRestraint.html", "classIMP_1_1em2d_1_1ParticlesDummyRestraint" ],
    [ "PolarResamplingParameters", "classIMP_1_1em2d_1_1PolarResamplingParameters.html", "classIMP_1_1em2d_1_1PolarResamplingParameters" ],
    [ "ProjectionFinder", "classIMP_1_1em2d_1_1ProjectionFinder.html", "classIMP_1_1em2d_1_1ProjectionFinder" ],
    [ "ProjectionMask", "classIMP_1_1em2d_1_1ProjectionMask.html", "classIMP_1_1em2d_1_1ProjectionMask" ],
    [ "ProjectionParameters", "classIMP_1_1em2d_1_1ProjectionParameters.html", "classIMP_1_1em2d_1_1ProjectionParameters" ],
    [ "ProjectionParametersScoreState", "classIMP_1_1em2d_1_1ProjectionParametersScoreState.html", "classIMP_1_1em2d_1_1ProjectionParametersScoreState" ],
    [ "ProjectionStates", "classIMP_1_1em2d_1_1ProjectionStates.html", "classIMP_1_1em2d_1_1ProjectionStates" ],
    [ "RegistrationResult", "classIMP_1_1em2d_1_1RegistrationResult.html", "classIMP_1_1em2d_1_1RegistrationResult" ],
    [ "ScoreFunction", "classIMP_1_1em2d_1_1ScoreFunction.html", "classIMP_1_1em2d_1_1ScoreFunction" ],
    [ "SegmentationParameters", "classIMP_1_1em2d_1_1SegmentationParameters.html", "classIMP_1_1em2d_1_1SegmentationParameters" ],
    [ "SpiderImageReaderWriter", "classIMP_1_1em2d_1_1SpiderImageReaderWriter.html", "classIMP_1_1em2d_1_1SpiderImageReaderWriter" ]
];

==> imp-doc-2.1.1.tar.gz: html/namespaceIMP_1_1em2d.js <==
var namespaceIMP_1_1em2d =
[
    [ "argminmax", "namespaceIMP_1_1em2d_1_1argminmax.html", null ],
    [ "buildxlinks", "namespaceIMP_1_1em2d_1_1buildxlinks.html", "namespaceIMP_1_1em2d_1_1buildxlinks" ],
    [ "csv_related", "namespaceIMP_1_1em2d_1_1csv__related.html", null ],
    [ "Database", "namespaceIMP_1_1em2d_1_1Database.html", "namespaceIMP_1_1em2d_1_1Database" ],
    [ "DominoModel", null, [
      [ "DominoModel", "classIMP_1_1em2d_1_1DominoModel_1_1DominoModel.html", "classIMP_1_1em2d_1_1DominoModel_1_1DominoModel" ]
    ] ],
    [ "MonteCarloRelativeMoves", null, [
      [ "MonteCarloRelativeMoves", "classIMP_1_1em2d_1_1MonteCarloRelativeMoves_1_1MonteCarloRelativeMoves.html", "classIMP_1_1em2d_1_1MonteCarloRelativeMoves_1_1MonteCarloRelativeMoves" ]
    ] ],
    [ "restraints", "namespaceIMP_1_1em2d_1_1restraints.html", null ],
    [ "solutions_io", "namespaceIMP_1_1em2d_1_1solutions__io.html", "namespaceIMP_1_1em2d_1_1solutions__io" ],
    [ "CenteredMat", "classIMP_1_1em2d_1_1CenteredMat.html", "classIMP_1_1em2d_1_1CenteredMat" ],
    [ "ChiSquaredScore", "classIMP_1_1em2d_1_1ChiSquaredScore.html", "classIMP_1_1em2d_1_1ChiSquaredScore" ],
    [ "CollisionCrossSection", "classIMP_1_1em2d_1_1CollisionCrossSection.html", "classIMP_1_1em2d_1_1CollisionCrossSection" ],
    [ "DistanceFilter", "classIMP_1_1em2d_1_1DistanceFilter.html", "classIMP_1_1em2d_1_1DistanceFilter" ],
    [ "DistanceFilterTable", "classIMP_1_1em2d_1_1DistanceFilterTable.html", "classIMP_1_1em2d_1_1DistanceFilterTable" ],
    [ "DummyRestraint", "classIMP_1_1em2d_1_1DummyRestraint.html", "classIMP_1_1em2d_1_1DummyRestraint" ],
    [ "Em2DRestraint", "classIMP_1_1em2d_1_1Em2DRestraint.html", "classIMP_1_1em2d_1_1Em2DRestraint" ],
    [ "EM2DScore", "classIMP_1_1em2d_1_1EM2DScore.html", "classIMP_1_1em2d_1_1EM2DScore" ],
    [ "Fine2DRegistrationRestraint", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint" ],
    [ "GridStates", "classIMP_1_1em2d_1_1GridStates.html", "classIMP_1_1em2d_1_1GridStates" ],
    [ "HasHigherCCC", "classIMP_1_1em2d_1_1HasHigherCCC.html", "classIMP_1_1em2d_1_1HasHigherCCC" ],
    [ "HasLowerScore", "classIMP_1_1em2d_1_1HasLowerScore.html", "classIMP_1_1em2d_1_1HasLowerScore" ],
    [ "Image", "classIMP_1_1em2d_1_1Image.html", "classIMP_1_1em2d_1_1Image" ],
    [ "ImageReaderWriter", "classIMP_1_1em2d_1_1ImageReaderWriter.html", "classIMP_1_1em2d_1_1ImageReaderWriter" ],
    [ "JPGImageReaderWriter", "classIMP_1_1em2d_1_1JPGImageReaderWriter.html", "classIMP_1_1em2d_1_1JPGImageReaderWriter" ],
    [ "LessPairBySecond", "classIMP_1_1em2d_1_1LessPairBySecond.html", "classIMP_1_1em2d_1_1LessPairBySecond" ],
    [ "MasksManager", "classIMP_1_1em2d_1_1MasksManager.html", "classIMP_1_1em2d_1_1MasksManager" ],
    [ "MatchTemplateResult", "classIMP_1_1em2d_1_1MatchTemplateResult.html", "classIMP_1_1em2d_1_1MatchTemplateResult" ],
    [ "MeanAbsoluteDifference", "classIMP_1_1em2d_1_1MeanAbsoluteDifference.html", "classIMP_1_1em2d_1_1MeanAbsoluteDifference" ],
    [ "ParticlesDummyRestraint", "classIMP_1_1em2d_1_1ParticlesDummyRestraint.html", "classIMP_1_1em2d_1_1ParticlesDummyRestraint" ],
    [ "PolarResamplingParameters", "classIMP_1_1em2d_1_1PolarResamplingParameters.html", "classIMP_1_1em2d_1_1PolarResamplingParameters" ],
    [ "ProjectingOptions", "classIMP_1_1em2d_1_1ProjectingOptions.html", "classIMP_1_1em2d_1_1ProjectingOptions" ],
    [ "ProjectingParameters", "classIMP_1_1em2d_1_1ProjectingParameters.html", "classIMP_1_1em2d_1_1ProjectingParameters" ],
    [ "ProjectionFinder", "classIMP_1_1em2d_1_1ProjectionFinder.html", "classIMP_1_1em2d_1_1ProjectionFinder" ],
    [ "ProjectionMask", "classIMP_1_1em2d_1_1ProjectionMask.html", "classIMP_1_1em2d_1_1ProjectionMask" ],
    [ "ProjectionParameters", "classIMP_1_1em2d_1_1ProjectionParameters.html", "classIMP_1_1em2d_1_1ProjectionParameters" ],
    [ "ProjectionParametersScoreState", "classIMP_1_1em2d_1_1ProjectionParametersScoreState.html", "classIMP_1_1em2d_1_1ProjectionParametersScoreState" ],
    [ "ProjectionStates", "classIMP_1_1em2d_1_1ProjectionStates.html", "classIMP_1_1em2d_1_1ProjectionStates" ],
    [ "RegistrationResult", "classIMP_1_1em2d_1_1RegistrationResult.html", "classIMP_1_1em2d_1_1RegistrationResult" ],
    [ "RelativePositionMover", "classIMP_1_1em2d_1_1RelativePositionMover.html", "classIMP_1_1em2d_1_1RelativePositionMover" ],
    [ "RigidBodiesImageFitRestraint", "classIMP_1_1em2d_1_1RigidBodiesImageFitRestraint.html", "classIMP_1_1em2d_1_1RigidBodiesImageFitRestraint" ],
    [ "ScoreFunction", "classIMP_1_1em2d_1_1ScoreFunction.html", "classIMP_1_1em2d_1_1ScoreFunction" ],
    [ "SegmentationParameters", "classIMP_1_1em2d_1_1SegmentationParameters.html", "classIMP_1_1em2d_1_1SegmentationParameters" ],
    [ "SpiderImageReaderWriter", "classIMP_1_1em2d_1_1SpiderImageReaderWriter.html", "classIMP_1_1em2d_1_1SpiderImageReaderWriter" ],
    [ "TIFFImageReaderWriter", "classIMP_1_1em2d_1_1TIFFImageReaderWriter.html", "classIMP_1_1em2d_1_1TIFFImageReaderWriter" ]
];
